@@ -1,4 +1,4 @@
-/* Copyright (C) 2017-2020 Greenbone Networks GmbH
+/* Copyright (C) 2017-2021 Greenbone Networks GmbH
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -15,9 +15,9 @@
  * You should have received a copy of the GNU Affero General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
-import {parseCsv} from '../parser';
+import {parseCsv} from 'gmp/parser';
 
-import Model from '../model';
+import Model from 'gmp/model';
 
 class Role extends Model {
   static entityType = 'role';
