@@ -1,4 +1,4 @@
-/* Copyright (C) 2017-2020 Greenbone Networks GmbH
+/* Copyright (C) 2017-2021 Greenbone Networks GmbH
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -21,7 +21,7 @@ import {isEmpty} from 'gmp/utils/string';
 
 import {parseInt} from 'gmp/parser';
 
-import Model from '../model';
+import Model from 'gmp/model';
 
 class Tag extends Model {
   static entityType = 'tag';
