@@ -1,4 +1,4 @@
-/* Copyright (C) 2018-2020 Greenbone Networks GmbH
+/* Copyright (C) 2018-2021 Greenbone Networks GmbH
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -16,8 +16,6 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-import 'core-js/features/array/find';
-
 import memoize from 'memoize-one';
 
 import React from 'react';
@@ -109,12 +107,8 @@ const getXScale = memoize((data = [], timeline = false, width) => {
     xDomain =
       data.length === 1
         ? [
-            date(data[0].x)
-              .subtract(1, 'day')
-              .toDate(),
-            date(data[0].x)
-              .add(1, 'day')
-              .toDate(),
+            date(data[0].x).subtract(1, 'day').toDate(),
+            date(data[0].x).add(1, 'day').toDate(),
           ]
         : [date(xMin).toDate(), date(xMax).toDate()];
   } else {
@@ -152,10 +146,11 @@ const getY2Scale = memoize((data = [], height) => {
 });
 
 export const lineDataPropType = PropTypes.shape({
-  label: PropTypes.any.isRequired,
   color: PropTypes.toString.isRequired,
-  width: PropTypes.number,
   dashArray: PropTypes.string,
+  label: PropTypes.any.isRequired,
+  lineWidth: PropTypes.number,
+  width: PropTypes.number,
 });
 
 const crossPropTypes = {
