@@ -1,4 +1,4 @@
-/* Copyright (C) 2017-2020 Greenbone Networks GmbH
+/* Copyright (C) 2017-2021 Greenbone Networks GmbH
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -16,8 +16,6 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-import 'core-js/features/array/find';
-
 import React from 'react';
 
 import styled from 'styled-components';
@@ -80,7 +78,7 @@ import PropTypes from 'web/utils/proptypes';
 import HostDetails from './details';
 import HostComponent from './component';
 
-const ToolBarIcons = ({
+export const ToolBarIcons = ({
   entity,
   onHostCreateClick,
   onHostDeleteClick,
