@@ -1,4 +1,4 @@
-/* Copyright (C) 2018-2020 Greenbone Networks GmbH
+/* Copyright (C) 2018-2021 Greenbone Networks GmbH
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -16,8 +16,6 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-import 'core-js/features/object/entries';
-
 import React from 'react';
 import {connect} from 'react-redux';
 
@@ -114,22 +112,12 @@ import TableRow from 'web/components/table/row';
 import compose from 'web/utils/compose';
 import Languages, {BROWSER_LANGUAGE} from 'web/utils/languages';
 import PropTypes from 'web/utils/proptypes';
-import {
-  SEVERITY_CLASS_NIST,
-  SEVERITY_CLASS_BSI,
-  SEVERITY_CLASS_PCI_DSS,
-} from 'web/utils/severity';
 import withCapabilities from 'web/utils/withCapabilities';
 import withGmp from 'web/utils/withGmp';
 
 import SettingsDialog from './dialog';
 
 const FIRST_COL_WIDTH = '250px';
-export const SEVERITY_CLASSES = [
-  {id: SEVERITY_CLASS_NIST, name: 'NVD Vulnerability Severity Ratings'},
-  {id: SEVERITY_CLASS_BSI, name: 'BSI Schwachstellenampel (Germany)'},
-  {id: SEVERITY_CLASS_PCI_DSS, name: 'PCI-DSS'},
-];
 
 const getLangNameByCode = code => {
   const language = Languages[code];
@@ -265,13 +253,6 @@ class UserSettings extends React.Component {
     }
   }
 
-  getSeverityClassNameById(id) {
-    const specifiedClass = SEVERITY_CLASSES.find(clas => {
-      return clas.id === id;
-    });
-    return isDefined(specifiedClass) ? specifiedClass.name : undefined;
-  }
-
   handleSaveSettings(data) {
     const {gmp} = this.props;
     const {userInterfaceLanguage = BROWSER_LANGUAGE, timezone} = data;
@@ -316,7 +297,6 @@ class UserSettings extends React.Component {
       detailsExportFileName = {},
       listExportFileName = {},
       reportExportFileName = {},
-      severityClass = {},
       dynamicSeverity = {},
       defaultSeverity = {},
       defaultAlert = {},
@@ -500,12 +480,6 @@ class UserSettings extends React.Component {
                     <Table>
                       <colgroup width={FIRST_COL_WIDTH} />
                       <TableBody>
-                        <TableRow title={severityClass.comment}>
-                          <TableData>{_('Severity Class')}</TableData>
-                          <TableData>
-                            {this.getSeverityClassNameById(severityClass.value)}
-                          </TableData>
-                        </TableRow>
                         <TableRow title={dynamicSeverity.comment}>
                           <TableData>{_('Dynamic Severity')}</TableData>
                           <TableData>
@@ -807,9 +781,6 @@ class UserSettings extends React.Component {
               listExportFileName={listExportFileName.value}
               reportExportFileName={reportExportFileName.value}
               autoCacheRebuild={autoCacheRebuild.value}
-              severityClass={
-                severityClass.value === '' ? undefined : severityClass.value
-              }
               dynamicSeverity={dynamicSeverity.value}
               defaultSeverity={defaultSeverity.value}
               defaultAlert={defaultAlert.id}
@@ -935,7 +906,6 @@ UserSettings.propTypes = {
   schedulesFilter: PropTypes.object,
   setLocale: PropTypes.func.isRequired,
   setTimezone: PropTypes.func.isRequired,
-  severityClass: PropTypes.object,
   tagsFilter: PropTypes.object,
   targets: PropTypes.array,
   targetsFilter: PropTypes.object,
@@ -969,7 +939,6 @@ const mapStateToProps = rootState => {
   const maxRowsPerPage = userDefaultsSelector.getByName('maxrowsperpage');
   const autoCacheRebuild = userDefaultsSelector.getByName('autocacherebuild');
 
-  const severityClass = userDefaultsSelector.getByName('severityclass');
   const defaultSeverity = userDefaultsSelector.getByName('defaultseverity');
   const dynamicSeverity = userDefaultsSelector.getByName('dynamicseverity');
 
@@ -1101,7 +1070,6 @@ const mapStateToProps = rootState => {
     listExportFileName,
     reportExportFileName,
     maxRowsPerPage,
-    severityClass,
     defaultSeverity,
     dynamicSeverity,
     isLoading: userDefaultsSelector.isLoading(),
@@ -1205,10 +1173,7 @@ const mapDispatchToProps = (dispatch, {gmp}) => ({
 export default compose(
   withGmp,
   withCapabilities,
-  connect(
-    mapStateToProps,
-    mapDispatchToProps,
-  ),
+  connect(mapStateToProps, mapDispatchToProps),
 )(UserSettings);
 
 // vim: set ts=2 sw=2 tw=80:
