@@ -1,4 +1,4 @@
-/* Copyright (C) 2009-2019 Greenbone Networks GmbH
+/* Copyright (C) 2009-2021 Greenbone Networks GmbH
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -507,8 +507,12 @@ char *
 get_system_reports_gmp (gvm_connection_t *, credentials_t *, params_t *,
                         cmd_response_data_t *);
 char *
-get_system_report_gmp (gvm_connection_t *, credentials_t *, const char *,
-                       params_t *, cmd_response_data_t *);
+get_system_report_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                       cmd_response_data_t *);
+char *
+get_system_report_gmp_from_url (gvm_connection_t *, credentials_t *,
+                                const char *, params_t *,
+                                cmd_response_data_t *);
 
 char *
 get_report_format_gmp (gvm_connection_t *, credentials_t *, params_t *,
